=== modified file 'breezy/plugins/commitfromnews/__init__.py'
--- breezy/plugins/commitfromnews/__init__.py	2017-07-23 19:18:44 +0000
+++ breezy/plugins/commitfromnews/__init__.py	2017-07-23 20:13:37 +0000
@@ -18,10 +18,12 @@
 
 commitfromnews is enabled by default when installed.
 
-To use, just do a commit where the NEWS file for your project has a new section
+To use, set the ``commit.template_from_files`` setting to a path and
+just do a commit where the NEWS file for your project has a new section
 added without providing a message to commit.
 
 E.g.::
+  $ echo "commit.template_from_files = NEWS" >> .bzr/branch/branch.conf
   $ echo "\n* new thing\n" >> NEWS
   $ bzr commit
   # editor pops open to let you tweak the message, and it starts with
@@ -40,13 +42,16 @@
     )
 
 option_registry.register(
-    ListOption('commit.templatefromfiles'))
+    ListOption('commit.template_from_files', default=[], help="""\
+List of fnmatch(2)-style shell file patterns to use when creating commit
+templates.
+"""))
 
 
 def commit_template(commit, message):
     """Create a commit message for commit based on changes in the tree."""
     config_stack = commit.work_tree.get_config_stack()
-    filespec = config_stack.get('commit.templatefromfiles')
+    filespec = config_stack.get('commit.template_from_files')
     if filespec:
         from .committemplate import CommitTemplate
         template = CommitTemplate(commit, message, filespec)

=== modified file 'breezy/plugins/commitfromnews/committemplate.py'
--- breezy/plugins/commitfromnews/committemplate.py	2017-07-23 19:18:44 +0000
+++ breezy/plugins/commitfromnews/committemplate.py	2017-07-23 20:13:37 +0000
@@ -26,16 +26,16 @@
 
 class CommitTemplate(object):
 
-    def __init__(self, commit, message, filespec):
+    def __init__(self, commit, message, file_matches):
         """Create a commit template for commit with initial message message.
 
         :param commit: A Commit object for the in progress commit.
         :param message: The current message (which may be None).
-        :param filespec: File specification list
+        :param file_matches: Check whether file matches
         """
         self.commit = commit
         self.message = message
-        self.filespec = filespec
+        self.file_matches = file_matches
 
     def make(self):
         """Make the template.
@@ -48,7 +48,7 @@
         found_old_path = None
         found_entry = None
         for old_path, new_path, fileid, entry in delta:
-            if new_path in self.filespec:
+            if self.file_matches(new_path):
                 found_entry = entry
                 found_old_path = old_path
                 break

